<?php
/*------------------------------------------------------------------------
# Copyright (C) 2012-2015 WebxSolution Ltd. All Rights Reserved.
# @license - GPLv2.0
# Author: WebxSolution Ltd
# Websites:  http://www.webxsolution.com
# Terms of Use: An extension that is derived from the JoomlaCK editor will only be allowed under the following conditions: http://joomlackeditor.com/terms-of-use
# ------------------------------------------------------------------------*/ 

defined('_JEXEC') or die;

/**
 *Ark inline content Article Context Class
 *
 * @package     Inlinecontent.Contexts
 * @subpackage  Inlinecontent.contexts.ZooImage
 */
 
require_once(JPATH_ADMINISTRATOR.'/components/com_zoo/config.php');
  
class ARKContextsZooImage extends ARKContextsBase
{
	private $zoo;
	private $item;
	private $element;
	private $params;
	private $layout;

	public function __construct($id)
	{
		$this->zoo = App::getInstance('zoo'); 
		$this->table = $this->zoo->table->item;
		list($id, $element_id,$layout) = explode('_',$id);
		$this->item = $this->table->get($id);
		if($this->item)
		{	
			$this->element = $this->item->getElement($element_id);
			$this->element = $this->item->getElement($element_id);
			$this->layout = $layout;
			$position = 'media';
			$application = $this->item->getApplication();
			$template = $application->getTemplate();
			$renderer = $this->zoo->renderer->create('item')->addPath(array($this->zoo->path->path('component.site:'), $template->getPath()));
			$renderer->setItem($this->item);

			$config = $renderer->getConfig('item')->get($application->getGroup().'.'.$this->item->getType()->id.'.'.$layout);
			$config = $config && isset($config[$position]) ? $config[$position] : array();
			
			$this->params = array();
			foreach ($config as $index => $data) 
			{
				if ($this->element->identifier == $data['element']) 
				{
					$this->params = $this->zoo->data->create($data);
					break;	
				}
			}
			if(is_array($this->params))
				  $this->params = $this->zoo->data->create($this->params);
		}  
		parent::__construct($id);		
	}	


    public function get()
	{
		if($this->id == null)
			return parent::get();	
			
		$file 	= $this->element->get('file');
		$file = JURI::root().$file;
		$title 	= $this->element->get('title');
			
	 	if ($this->params->get('link_to_item', false)) 
		{

		$title = empty($title) ? $this->item->name : $title;

		}
	        
		$title  = $title ? ' title="'.htmlspecialchars($title, ENT_QUOTES, 'UTF-8').'"' : '';
		$alt = $title;
		
		$image= '<img src="'.$file.'"'.$title.$alt.' />';

		return array( 'title'=>'','data'=>$image);	

	}
	
	
	
	public function triggerContentPlugins($rawText)
	{
		if(isset($rawText))
		{
			$dom = new DOMDocument();
			$dom->strictErrorChecking = false;
			$dom->recover = true;
			@$dom->loadHTML('<div>'.$rawText.'</div>');
		
			$images = $dom->getElementsByTagName('img');
			$image = $images->item(0);
			
			$src = $image->getAttribute('src');
			$file = str_replace(JURI::base(),JPATH_ROOT.'/',$src);
			$alt = $image->getAttribute('alt');
			$alt  = $alt ? ' alt="'.htmlspecialchars($alt, ENT_QUOTES, 'UTF-8').'"' : '';
			$title = $image->getAttribute('title');
			
			if ($this->params->get('link_to_item', false)) 
			{
				$title = empty($title) ? $this->item->name : $title;
			}
			
			$title  = $title ? ' title="'.htmlspecialchars($title, ENT_QUOTES, 'UTF-8').'"' : '';
			
			
			$file  = $this->zoo->zoo->resizeImage($file, $this->params->get('width', 0), $this->params->get('height', 0));
			$link   = JURI::base() . $this->zoo->path->relative($file);
			
			$info = getimagesize($link);
			$img = '<img src="'.$link.'"'.$title.' alt="'.$alt.'" '.$info[3].' />';
		}	
			
		return array( 'data'=>$img);
	}
			
	public function save($data,$type = 'body')
	{
		if($this->id == null)
			return array( 'title'=>'','data'=>'');	
		
		$img = base64_decode($data['articletext']);
		
		$dom = new DOMDocument();
		$dom->strictErrorChecking = false;
		$dom->recover = true;
		$dom->loadHTML('<div>'.$img.'</div>');
	
		$images = $dom->getElementsByTagName('img');
		$image = $images->item(0);
		$src = $image->getAttribute('src');
		$file = str_replace(JURI::base(),'',$src);
		
		$title = $image->getAttribute('title');
		
		$data = array('title'=>$title,'file'=>$file);
		
		$this->element->bindData($data);
						
		$this->table->save($this->item);
		
		//Let's save version manually as we cannot use JTableObserverContenthistory in this case!
		JTable::addIncludePath(JPATH_PLUGINS.'/system/zooinlineeditable/tables'); 
		
		$dataObject = new stdclass;
		
		$dataObject->id =  crc32($this->id.'_'.$this->element->identifier.'_'.$this->layout);
		$dataObject->name = $this->element->config->get('name');
		
		$alt = $image->getAttribute('alt');
		$alt  = $alt ? htmlspecialchars($alt, ENT_QUOTES, 'UTF-8') : '';
		if ($this->params->get('link_to_item', false)) 
		{
			$title = empty($title) ? $this->item->name : $this->element->get('title');
		}
		$title  = $title ? ' title="'.htmlspecialchars($title, ENT_QUOTES, 'UTF-8').'"' : '';
		
		$dataObject->data = '<img src="'.JURI::base().$file.'"'.$title.' alt="'.$alt.'" />';
		
		$typeAlias = 'com_zoo.image';	
		$historyTable = JTable::getInstance('Contenthistory', 'JTable');
		$typeTable = JTable::getInstance('Contenttype', 'JTable');
		$typeTable->load(array('type_alias' => $typeAlias ));
		$historyTable->set('ucm_type_id', $typeTable->type_id);

		$historyTable->set('ucm_item_id', $dataObject->id);

		// Don't store unless we have a non-zero item id
		if ($historyTable->ucm_item_id)
		{
			$historyTable->set('version_data', json_encode($dataObject));
			$input = JFactory::getApplication()->input;
			$data = $input->get('jform', array(), 'array');
			$versionName = false;

			if (isset($data['version_note']))
			{
				$versionName = JFilterInput::getInstance()->clean($data['version_note'], 'string');
				$historyTable->set('version_note', $versionName);
			}

			// Don't save if hash already exists and same version note
			$historyTable->set('sha1_hash', $historyTable->getSha1($dataObject, $typeTable));

			if ($historyRow = $historyTable->getHashMatch())
			{
				if (!$versionName || ($historyRow->version_note == $versionName))
				{
				}
				else
				{
					// Update existing row to set version note
					$historyTable->set('version_id', $historyRow->version_id);
				}
			}

			$result = $historyTable->store();

			// Load history_limit config from extension.
			$aliasParts = explode('.', $typeAlias);

			if ($maxVersions = JComponentHelper::getParams($aliasParts[0])->get('history_limit', 0))
			{
				$historyTable->deleteOldVersions($maxVersions);
			}

		}
		
		//We need to process data as we are sending it back to the client
		$alt = $image->getAttribute('alt');
		$alt  = $alt ? htmlspecialchars($alt, ENT_QUOTES, 'UTF-8') : '';
		if ($this->params->get('link_to_item', false)) 
		{
			$title = empty($title) ? $this->item->name : $this->element->get('title');
		}
		$title  = $title ? ' title="'.htmlspecialchars($title, ENT_QUOTES, 'UTF-8').'"' : '';
		
		$file  = $this->zoo->zoo->resizeImage(JPATH_ROOT.'/'.$file, $this->params->get('width', 0), $this->params->get('height', 0));
		
		$link   = JURI::base() . $this->zoo->path->relative($file);
	
		$info = getimagesize($link);
		$img = '<img src="'.$link.'"'.$title.' alt="'.$alt.'" '.$info[3].' />';	
														
		return array( 'title'=>'','data'=>$img,'message'=>'');	
	}
	
	public function version($versionId,$type)
	{
		$historyTable = JTable::getInstance('Contenthistory');
		$historyTable->load($versionId);
		$rowArray = JArrayHelper::fromObject(json_decode($historyTable->version_data));
			
		$item = JTable::getInstance('element','ZOOTable');

		$item->bind($rowArray);	
	
		$text = '';
		
		$text = $item->data;
	
		return array( 'data'=>$text);
	}
	
}