<?php
/*------------------------------------------------------------------------
# Copyright (C) 2012-2015 WebxSolution Ltd. All Rights Reserved.
# @license - GPLv2.0
# Author: WebxSolution Ltd
# Websites:  http://www.webxsolution.com
# Terms of Use: An extension that is derived from the JoomlaCK editor will only be allowed under the following conditions: http://joomlackeditor.com/terms-of-use
# ------------------------------------------------------------------------*/ 

defined('_JEXEC') or die;

/**
 *Ark inline content Article Context Class
 *
 * @package     Inlinecontent.Contexts
 * @subpackage  Inlinecontent.contexts.ZooTextarea
 */
 
require_once(JPATH_ADMINISTRATOR.'/components/com_zoo/config.php');
  
class ARKContextsZooTextarea extends ARKContextsBase
{
	private $zoo;
	private $item;
	private $element;
	private $position;

	public function __construct($id)
	{
		$this->zoo = App::getInstance('zoo'); 
		$this->table = $this->zoo->table->item;
		list($id, $element_id,$position) = explode('_',$id);
		$this->item = $this->table->get($id);
		if($this->item)
			$this->element = $this->item->getElement($element_id);
		$this->position = $position;
		parent::__construct($id);		
	}	


    public function get()
	{
		if($this->id == null)
			return parent::get();	
		
		$this->element->seek($this->position);
		$textarea = $this->element->get('value',$this->element->config->get('default',''));

		return array( 'title'=>'','data'=>$textarea);	

	}
	
	
	
	public function triggerContentPlugins($rawText)
	{
		
		$item = new stdclass;
					
		$item->text = '';
		if(isset($rawText))
		{
			$item->text = $rawText;
			$params = array('inline'=>false); //set this so that we don't trigger the inline content plugins
			$dispatcher	= JEventDispatcher::getInstance();
			JPluginHelper::importPlugin('content');
			$dispatcher->trigger('onContentPrepare', array ('com_zoo.element.textarea', &$item, &$params, 0));
		}	
			
		return array( 'data'=>$item->text);
	}
			
	public function save($data,$type = 'body')
	{
		if($this->id == null)
			return array( 'title'=>'','data'=>'');	
		
		$text = base64_decode($data['articletext']);
	
		$this->element->seek($this->position);
		$this->element->set('value',$text);
						
		$this->table->save($this->item);
		
		$dataObject = new stdclass;
		
		$dataObject->id =  crc32($this->id.'_'.$this->element->identifier.'_'.$this->position);
		$dataObject->name = $this->element->config->get('name');
		$this->element->seek($this->position);
		$dataObject->data = $this->element->get('value');
		
		$typeAlias = 'com_zoo.textarea';	

		$historyTable = JTable::getInstance('Contenthistory', 'JTable');
		$typeTable = JTable::getInstance('Contenttype', 'JTable');
		$typeTable->load(array('type_alias' => $typeAlias ));
		$historyTable->set('ucm_type_id', $typeTable->type_id);

		$historyTable->set('ucm_item_id', $dataObject->id);

		// Don't store unless we have a non-zero item id
		if ($historyTable->ucm_item_id)
		{
			$historyTable->set('version_data', json_encode($dataObject));
			$input = JFactory::getApplication()->input;
			$data = $input->get('jform', array(), 'array');
			$versionName = false;

			if (isset($data['version_note']))
			{
				$versionName = JFilterInput::getInstance()->clean($data['version_note'], 'string');
				$historyTable->set('version_note', $versionName);
			}

			// Don't save if hash already exists and same version note
			$historyTable->set('sha1_hash', $historyTable->getSha1($dataObject, $typeTable));

			if ($historyRow = $historyTable->getHashMatch())
			{
				if (!$versionName || ($historyRow->version_note == $versionName))
				{
				}
				else
				{
					// Update existing row to set version note
					$historyTable->set('version_id', $historyRow->version_id);
				}
			}

			$result = $historyTable->store();

			// Load history_limit config from extension.
			$aliasParts = explode('.', $typeAlias);

			if ($maxVersions = JComponentHelper::getParams($aliasParts[0])->get('history_limit', 0))
			{
				$historyTable->deleteOldVersions($maxVersions);
			}

		}

		//We need to process data as we are sending it back to the client
		
		$item = new stdclass;
		$this->element->seek($this->position);
		$item->text = $this->element->get('value',$this->element->config->get('default',''));
		
		
		//let's detect if any plugin tags are being used 
		//if so let's inform the system to warn the user
		$message = $this->detectPluginTags($item->text);	

		$params =  array('inline'=>false);
		$dispatcher	= JEventDispatcher::getInstance();
		JPluginHelper::importPlugin('content');
		$dispatcher->trigger('onContentPrepare', array ('com_zoo.element.textarea', &$item, &$params, 0));
												
		return array( 'title'=>'','data'=>$item->text,'message'=>$message);		
	}
	
	public function version($versionId,$type)
	{
				
		$historyTable = JTable::getInstance('Contenthistory');
		$historyTable->load($versionId);
		$rowArray = JArrayHelper::fromObject(json_decode($historyTable->version_data));
			
		$item = JTable::getInstance('element','ZOOTable');

		$item->bind($rowArray);	
	
		$text = '';
		
		$text = $item->data;
	
		return array( 'data'=>$text);
	}
}