<?php
/**
 * @package   System - ZOO Event
 * @author    YOOtheme http://www.yootheme.com
 * @copyright Copyright (C) YOOtheme GmbH
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.plugin.plugin');

if(!class_exists('App'))
{	
	JTable::addIncludePath(JPATH_PLUGINS.'/system/zooinlineeditable/tables'); 
}
class plgSystemZooInlineEditable extends JPlugin {

	public $app;
	private $isEnabled = true;
	
	protected $_types = array('com_zoo.textarea','com_zoo.image');
	
	public static $instances;

	/**
	 * onAfterInitialise handler
	 *
	 * Adds ZOO event listeners
	 *
	 * @access public
	 * @return null
	 */
	public function onAfterInitialise() {

		//Inline editing is only enabled for frontend editing	
		if ($this->app->isAdmin())
		{
			return;
		}
		
        $user = JFactory::getUser();
		
		//if user is guest lets bail
		if($user->get('guest'))
		{
			return;
		}
		
        $cParams = JComponentHelper::getParams('com_arkeditor');
		if(empty($cParams) ||!$cParams->get('enable_inline',true))
		{
			$this->isEnabled = false;
			return;
		}	

       if(!JPluginHelper::isEnabled('editors','arkeditor'))
            return;	
		
        if(!JPluginHelper::isEnabled('system','inlinecontent'))
            return;	
		
		// make sure ZOO exists
		if (!JComponentHelper::getComponent('com_zoo', true)->enabled) 
		{
			return;
		}

		// load ZOO config
		jimport('joomla.filesystem.file');
		if (!JFile::exists(JPATH_ADMINISTRATOR.'/components/com_zoo/config.php')) 
		{
			return;
		}
		
		
				
		require_once(JPATH_ADMINISTRATOR.'/components/com_zoo/config.php');

		// make sure App class exists
		if (!class_exists('App')) 
		{			
			return;
		}
		
		// Here are a number of events for demonstration purposes.
		// Have a look at administrator/components/com_zoo/config.php
		// and also at administrator/components/com_zoo/events/

		// Get the ZOO App instance
		$zoo = App::getInstance('zoo');
		
		$zoo = App::getInstance('zoo');
		$zoo->path->register(JPATH_PLUGINS.'/system/zooinlineeditable/elements', 'elements');
		
		// register event
		$zoo->event->dispatcher->connect('element:beforedisplay', array('plgSystemZooInlineEditable', 'beforeDisplay'));
	
	}
	
	public function onAfterRoute()
	{
		
			
		//Inline editing is only enabled for frontend editing	
		if ($this->app->isAdmin())
		{
			return;
		}
		
        $user = JFactory::getUser();
		
		//if user is guest lets bail
		if($user->get('guest'))
		{
			return;
		}
			
		
		if($this->app->input->get('option') == 'com_contenthistory' && in_array($this->app->input->get('type_alias',''), $this->_types))
		{		
			$uuid = $this->app->input->get('item_id',0);
			
			var_dump($uuid);
			
			if(is_int($uuid ))
				return;
			
			if(!$uuid)
				return;
			
			$item_id = crc32($uuid);
			$this->app->input->set('item_id',$item_id);
		
		}
		elseif($this->app->input->get('option') == 'com_contenthistory' &&  $this->app->input->get('type_alias') == 'com_zoo.category')
		{
			require_once JPATH_PLUGINS.'/system/zooinlineeditable/tables/category.php';
		}	
	
	}	

	public function beforeDisplay($event) 
	{

		 if(!JFactory::getApplication()->input->get('ark_inine_enabled',true))
		 	return;
		
		$zoo = App::getInstance('zoo');
		
		$item = $event->getSubject();
		$element = $event['element'];
		$identifier = $element->identifier;
		
		if(!isset(static::$instances))
		{
			static::$instances = array();
		}	
		//do whatever you'd like to do
		
		if(isset(static::$instances[$item->id.'_'.$identifier]))
			return;

		switch($element->config->get('type'))
		{
			case "text":
				if(is_subclass_of($element,'ElementRepeatable'))
				{
				
					$dispatcher = JEventDispatcher::getInstance();
					JPluginHelper::importPlugin('inline');
				
					if($element->config->get('repeatable'))
					{
						foreach ($element as $self) 
						{
							if (($text = $element->get('value',$element->config->get('default',''))) && !empty($text)) 
							{
								$dispatcher->trigger('editable',array(&$text, array('id'=>$item->id.'_'.$identifier.'_'.$element->key(),'context'=>'zoo',
																					'type'=>'title','style'=>'display:inline',
																					'itemtype'=>$element->config->get('type'))));
								$elementRef = $item->getElement($identifier);
								$elementRef->seek($element->key());
								$elementRef->set('value',$text);
							}
						}
					}
					else
					{
						if (($text = $element->get('value', $element->config->get('default',''))) && !empty($text)) 
						{
							$dispatcher->trigger('editable',array(&$text, array('id'=>$item->id.'_'.$identifier.'_'.$element->key(),'context'=>'zoo',
																				'type'=>'title','style'=>'display:inline',
																				'itemtype'=>$element->config->get('type'))));
							$item->getElement($identifier)->set('value',$text);
						}
					}	
				}
				else
				{
					
					$dispatcher = JEventDispatcher::getInstance();
					JPluginHelper::importPlugin('inline');
					
					if (($text = $this->get('value', $element->config->get('default',''))) && !empty($text)) 
					{
						$dispatcher->trigger('editable',array(&$text, array('id'=>$item->id.'_'.$identifier,'context'=>'zoo',
																			'type'=>'title','style'=>'display:inline',
																			'itemtype'=>$element->config->get('type'))));
						$item->getElement($identifier)->bindData(array('value'=>$text));
					}
				}
			break;	
			case "textarea":
				if(is_subclass_of($element,'ElementRepeatable'))
				{
				
					$dispatcher = JEventDispatcher::getInstance();
					JPluginHelper::importPlugin('inline');
				
					if($element->config->get('repeatable'))
					{
						foreach ($element as $self) 
						{
							if (($text = $element->get('value',$element->config->get('default',''))) && !empty($text)) 
							{
								$dispatcher->trigger('editable',array(&$text, array('id'=>$item->id.'_'.$identifier.'_'.$element->key(),'context'=>'zoo',
																					'type'=>'body','itemtype'=>$element->config->get('type'))));
								$elementRef = $item->getElement($identifier);
								$elementRef->seek($element->key());
								$elementRef->set('value',$text);
							}
						}
					}
					else
					{
						if (($text = $element->get('value', $element->config->get('default',''))) && !empty($text)) 
						{
							$dispatcher->trigger('editable',array(&$text, array('id'=>$item->id.'_'.$identifier.'_'.$element->key(),'context'=>'zoo',
																				'type'=>'body','itemtype'=>$element->config->get('type'))));
							$item->getElement($identifier)->set('value',$text);
						}
					}	
				}
				else
				{
					if (($text = $this->get('value', $element->config->get('default',''))) && !empty($text)) 
					{
						$dispatcher->trigger('editable',array(&$text, array('id'=>$item->id.'_'.$identifier,'context'=>'zoo',
																			'type'=>'body','itemtype'=>$element->config->get('type'))));
						$item->getElement($identifier)->bindData(array('value'=>$text));
					}
				}	
			
			break;
			case "itemname":
					$item->name = '{div class=__ARKQUOTE__editable__ARKQUOTE__ data-id=__ARKQUOTE__'.$item->id.'__ARKQUOTE__ data-context=__ARKQUOTE__zoo__ARKQUOTE__ data-type=__ARKQUOTE__title__ARKQUOTE__ data-itemtype=__ARKQUOTE__'.$element->config->get('type').'__ARKQUOTE__ contenteditable=__ARKQUOTE__true__ARKQUOTE__ style=__ARKQUOTE__display:inline;__ARKQUOTE__}'.$item->name.'{/div}'; 
			break;
		}	
		static::$instances[$item->id.'_'.$identifier] = $element;

	}

}
